@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0802';
+our $VERSION = '0.0803';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
@@ -281,15 +281,13 @@ Music::Intervals - Breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.0802
+version 0.0803
 
 =head1 SYNOPSIS
 
   use Music::Intervals;
 
-  my $m = Music::Intervals->new(
-    notes => [qw/C E G B/],
-  );
+  my $m = Music::Intervals->new(notes => [qw/C E G B/]);
 
   # Then any of:
   print Dumper(
@@ -315,9 +313,9 @@ version 0.0802
 
 =head1 DESCRIPTION
 
-A C<Music::Intervals> object shows the breakdown of musical notes,
-intervals and chords.  (See L<Music::Intervals::Numeric> to use
-integer ratios instead of named notes.)
+A C<Music::Intervals> object shows the breakdown of musical notes and
+intervals.  (See L<Music::Intervals::Numeric> to use integer ratios
+instead of named notes.)
 
 This module reveals the "guts" within a given tonality.  And by guts I
 mean, the measurements of the notes and the intervals between them.
@@ -438,8 +436,6 @@ L<http://en.wikipedia.org/wiki/Equal_temperament>
 
 L<http://en.wikipedia.org/wiki/Just_intonation>
 
-L<Music::Scala> - A powerful module encompassing thousands of scales and the ratios therein
-
 =head2 DEPENDENCIES
 
 L<Algorithm::Combinatorics>
@@ -450,8 +446,6 @@ L<MIDI::Pitch>
 
 L<Moo>
 
-L<Music::Intervals::Ratios>
-
 L<Music::Scales>
 
 L<Number::Fraction>
